unnest_term_list: Unnest a Nested Term List

Description Usage Arguments Value

Description

Term lists can be stored as lists within a list for use in termc_count in a hierarchical fashion. This structure is not always useful and can be taken to a single nest via unnest_term_list. The function detects if the term.list is nested or not and then unnests only if needed, thus allowing it to be safely used on both nested and unnested term.lists.

Usage

1
unnest_term_list(term.list, ...)

Arguments

term.list

A list of named character vectors. 'codeterm_count can be used in a hierarchical fashion as well; that is a list of regexes can be passed and counted and then a second (or more) pass can be taken wit a new set of regexes on only those rows/text elements that were left untagged (count rowSums is zero). This is accomplished by passing a list of lists of regexes. See Examples for the hierarchical terms section for a demonstration.

...

ignored.

Value

Returns a list of one level.


trinker/termcoLite documentation built on Oct. 23, 2021, 9:53 a.m.